@@ -1,4 +1,8 @@
-#R CMD BATCH --no-timing --no-restore --no-save adddata_test.R adddata_test.Rout
+# R CMD BATCH --no-timing --no-restore --no-save adddata_test.R adddata_test.Rout
+
+# Get rid of anything in the workspace:
+rm(list=ls()) 
+
 library(httk)
 
 # Number of chemicals distributed with the package:
