@@ -7,10 +7,9 @@ library(httk)
 
 head(solve_fetal_pbtk(chem.name = 'bisphenol a', daily.dose = 1,
                                              doses.per.day = 3))
-head(solve_fetal_pbtk(chem.cas="80-05-7"))
-head(solve_fetal_pbtk(parameters=parameterize_fetal_pbtk(chem.cas="80-05-7")))
 
-p <- parameterize_fetal_pbtk(chem.name='bisphenol a')[sort(names(parameterize_fetal_pbtk(chem.name='bisphenol a')))]
+p <- parameterize_fetal_pbtk(chem.name='bisphenol a')
+p <- p[sort(names(p))]
 # Try to standardize order of variable names
 for (this.param in names(p)[order(toupper(names(p)))]) cat(paste(this.param,": ",p[[this.param]],"\r\n",sep=""))
 
